//-*-C++-*- Header file for the MaintainDB Class
// Copyright (C) 1997 by John P. Weiss
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Artistic License, included as the file
// "LICENSE" in the source code archive.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//
// You should have received a copy of the file "LICENSE", containing
// the License John Weiss originally placed this program under.
//
// This file is unreadable, because the comment-docifier is
// brainedead.  Try a "make srcdocs" to generate the
// HTML-documentation.
//
#ifndef _MaintainDB_h_
#define _MaintainDB_h_
#include "AudioDev.h"
#include "WorkManDB.h"
#include "TiKanDB.h"
#include "APDialog.h"
#include "enums.h"
#include <qlabel.h>
#include <qlined.h>
#include <qlistbox.h>
#include <qpushbt.h>



//
#define STYLEFLAGS WStyle_Customize|WStyle_Title|WStyle_SysMenu

/**
  An \Ref{APDialog} for maintaining audio databases.

  The private members and methods are not documented; they exist
  solely to support the dialog box used to do the editing.

  @memo Maintains databases.
  @see WorkManDB, AudioDev
  */
class MaintainDB : public APDialog
{
	 //
	 Q_OBJECT

   public:
	 /**
	   A \Ref{WorkManDB} object for storing entries in a
	   WorkMan-style database.  Public so that outside functions can
	   initialize it.
	   @memo
	   */
	 WorkManDB wmcddb;
	 /**
	   A \Ref{TiKanDB} object for storing entries in a
	   xmcd-style database.  Public so that outside functions can
	   initialize it.
	   @memo
	   */
	 TiKanDB tkcddb;
	 /**
	   A \Ref{DBType} {\bf enum} indicating which databases to save
	   to.  Only does something if the database in question exists.
	   @memo
	   */
	 DBType saveTo;
	 /**
	   A \Ref{DBType} {\bf enum} indicating which databases to read
	   from.  Only does something if the database in question exists.
	   @memo
	   */
	 DBType readFrom;

	 /**
	   Class Constructor.  Requires an \Ref{AudioDev} pointer, from
	   which it gets the \Ref{Catalog} object to read from/store to
	   the database.  The parameters {\em wmcatname} and {\em
	   tkdbpath} contain the initial WorkManDB file and TiKanDB path,
	   respectively.
	   @memo
	   */
	 MaintainDB( AudioDev *devname, char *wmcatname=NULL,
			   char *tkdbpath=NULL );

	 /**
	   Class Destructor.
	   @memo
	   */
	 ~MaintainDB( void );

	 //
   public slots:
	 //
      /** 
	   {\em Public Slot}

	   Reads the \Ref{AudioDev}'s \Ref{ToC} from the database if it's
	   present.
	   @memo [{\tt public slot}]
	   */
	 void checkCatalog();
      /** 
	   {\em Public Slot} {\tt [virtual]}

	   Reimplemented from \Ref{APDialog}.  Calls the \Ref{AudioDev}'s
	   \Ref{cleanDisplay}() method to update any changes to the
	   \Ref{ToC}.	   
	   @memo [{\tt public slot}]
	   */
	 void open();

	 
   private:
	 //
	 QPushButton *saveb, *closeb, *cancelb, *undob;
	 QListBox *tracklist;
	 QLineEdit *track_eb, *title_eb, *artist_eb;
	 QLabel *tlb_txt, *edit_txt, *aeb_txt, *teb_txt;
	 QFrame *ctrlb_frame;
	 //
	 AudioDev *dev;
	 Catalog catcopy;
	 bool hasWMDB, hasTKDB;
	 //
	 void createChildren(QFont& dffont);
	 void connectChildren(void);

   private slots:
	 //
      void doUndo();
	 void doSave();
	 void newTitleStr();
	 void newArtistStr();
	 void newTrackStr();
	 void changeTrackEdit(int);
};

#endif // _MaintainDB_h_
//||||||||||||||||||||||||||||||||
//
// End
// 
