//-*-C++-*- Header file for the pAudio Class
// Copyright (C) 1997 by John P. Weiss
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
// This file is unreadable, because the comment-docifier is
// brainedead.  Try a "make srcdocs" to generate the
// HTML-documentation.
//
#ifndef _pAudio_h_
#define _pAudio_h_ 1
#include <qsize.h>
#include "PixButton.h"
#include "paneldefs.h"




/**
  {\bf pAudio} is a {\bf QWidget} with 6 audio control buttons:
  play/pause, stop, next track, previous track, scan forward, and scan
  backward.  The buttons are all public objects so that their slots
  can be accesses by non-member functions.

  @memo Six audio control buttons.
  @see PixButton, PixData
  */
class pAudio : public QWidget
{
   public:

	 //{@
	    ///
	 PixButton *ffb;
	    ///
	 PixButton *nextb;
	    ///
	 PixButton *playpauseb;
	    ///
	 PixButton *prevb;
	    ///
	 PixButton *rewb;
	    /** 
		 \Ref{ffb}, \Ref{nextb}, \Ref{playpauseb}, \Ref{prevb},
		 \Ref{rewb}, and \Ref{stopb} are the six \Ref{PixButton}
		 objects that make up this object.
		 @memo
		 */
	 PixButton *stopb;
	 //@}

	 /**
	   Class Constructor
	   @param parent The parent of this object
	   @param scale Determines the size of the \Ref{PixButton}s in
	   this object.  It's a multiplicative factor, so {\em scale}=2
	   means double the default size, and so on.
	   @memo
	   */
	 pAudio( QWidget *parent, float scale=1.0 );

	 /**
	   Class Destructor
	   @memo
	   */
	 ~pAudio(void);

	 /**
	   Moves the object, performing some internal bookkeeping at the
	   same time.
	   @memo
	   */
	 inline void moveAll( int x, int y );

	 /**
	   Overloaded version.
	   @memo
	   */
	 inline void moveAll( QPoint pos );

	 /**
	   @return The point in the x-direction where this widget ends.
	   @memo
	   */
	 inline QPoint xEndPt(void);

	 /**
	   @return The point in the y-direction where this widget ends.
	   @memo
	   */
	 inline QPoint yEndPt(void);

	 /**
	   Changes the palette of this object to {\em p}.
	   @memo
	   */
	 void changePalette(QPalette& p);
	 
   private:
	 void createChildren(float bscale);
	 void locateChildren(void);
	 void moveChildren(void);
	 //
	 QPoint fbw_p, stop_p, plps_p, prev_p, next_p, rew_p, ff_p;
	 QSize fbw_s;
	 // Only static const members can be initialized.  BUT - this
	 // member will be *identical* for all objects declared under
	 // this class because of the "static"!
	 static const int bsep=WIDGET_SEP;
};




//----------------------------------------------------------
//
// Inlined methods.
//
//----------------------------------------------------------




// Moves the entire Function widget, including the children.
//
inline void pAudio::moveAll( int x, int y )
{
  fbw_p.setX( x );
  fbw_p.setY( y );
  move( fbw_p );
}


// Overloaded version of the other function.
//
inline void pAudio::moveAll( QPoint pos )
{
  fbw_p = pos;
  move( fbw_p );
}


// Returns a point specifying where to put the next widget
//
inline QPoint pAudio::xEndPt( void )
{
  return( QPoint(fbw_s.width(),0) + fbw_p );
}


// As above, but in the y-direction
//
inline QPoint pAudio::yEndPt( void )
{
  return( QPoint(0,fbw_s.height()) + fbw_p );
}




#endif //_pAudio_h_
//||||||||||||||||||||||||||||||||
//
// End
// 
